Changelog
=========

1.0.1 (2018-01-16)
------------------

Bug fixes:

- Removed accidentally added plone.resourceeditor subdirectory.  [thet]


1.0 (2013-05-23)
----------------

- make sure theme is disable
  [vangheem]

- do not set value inside of pre tag since it can go crazy on some markup
  [vangheem]


1.0b4 (2013-01-01)
------------------

- Fixed a bug with saving files containing non-ASCII characters.
  [optilude]


1.0b3 (2012-10-16)
------------------

- Fix right click menu bug
  [optilude]

- Upgrade to latest version of ACE
  [optilude]


1.0b2 (2012-08-08)
------------------

- Upgrade to version 1.0 of the ACE editor
  [optilude]


1.0b1 (2012-08-08)
------------------

- Initial release
  [optilude]
